"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.movePhase = exports.deletePhase = exports.createPhase = exports.updatePhase = exports.getPhase = exports.listPhases = void 0;
const rest_modules_1 = require("@wix/sdk-runtime/rest-modules");
const timestamp_1 = require("@wix/sdk-runtime/transformations/timestamp");
const transform_paths_1 = require("@wix/sdk-runtime/transformations/transform-paths");
const rest_modules_2 = require("@wix/sdk-runtime/rest-modules");
function resolveComWixpressWorkflowApiV1PhasesServiceUrl(opts) {
    const domainToMappings = {
        'www._base_domain_': [
            {
                srcPath: '/_api/workflow-server-web',
                destPath: '',
            },
        ],
        'api._api_base_domain_': [
            {
                srcPath: '/workflow-server-web',
                destPath: '',
            },
        ],
        'manage._base_domain_': [
            {
                srcPath: '/_api/workflow-server-web',
                destPath: '',
            },
        ],
        'www.wixapis.com': [
            {
                srcPath: '/workflows',
                destPath: '',
            },
        ],
    };
    return (0, rest_modules_2.resolveUrl)(Object.assign(opts, { domainToMappings }));
}
const PACKAGE_NAME = '@wix/auto_sdk_workflows_phases';
/**
 * Retrieves a list of a workflow's phases.
 *
 *
 * The `listPhases()` function returns a Promise that resolves to a list containing information about the specified workflow's phases.
 *
 *
 * Use the `options` parameter to specify which phases to retrieve and in which order to retrieve them. Phases can be sorted based on their `"id"`, `"name"`, and `"position"`. If no `limit` parameter is passed, the first 50 cards are returned. Sort order defaults to by `"position"` ascending.
 *
 *
 * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
function listPhases(payload) {
    function __listPhases({ host }) {
        const metadata = {
            entityFqdn: 'wix.workflows.v1.phase',
            method: 'GET',
            methodFqn: 'com.wixpress.workflow.api.v1.PhasesService.ListPhases',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressWorkflowApiV1PhasesServiceUrl({
                protoPath: '/v1/workflows/{workflowId}/phases',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'phases.cardsList.cards.info.dueDate' },
                        { path: 'phases.cardsList.cards.info.createdAt' },
                        { path: 'phases.cardsList.cards.info.updatedAt' },
                        { path: 'phases.cardsList.cards.info.createdDate' },
                        { path: 'phases.cardsList.cards.info.updatedDate' },
                    ],
                },
            ]),
            fallback: [
                {
                    method: 'GET',
                    url: resolveComWixpressWorkflowApiV1PhasesServiceUrl({
                        protoPath: '/v1/workflows/{workflowId}/phases',
                        data: payload,
                        host,
                    }),
                    params: (0, rest_modules_1.toURLSearchParams)(payload),
                },
            ],
        };
        return metadata;
    }
    return __listPhases;
}
exports.listPhases = listPhases;
/**
 * Retrieves a phase by ID.
 *
 *
 * The `getPhase()` function returns a Promise that resolves to the phase with the specified ID.
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
function getPhase(payload) {
    function __getPhase({ host }) {
        const metadata = {
            entityFqdn: 'wix.workflows.v1.phase',
            method: 'GET',
            methodFqn: 'com.wixpress.workflow.api.v1.PhasesService.GetPhase',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressWorkflowApiV1PhasesServiceUrl({
                protoPath: '/v1/phases/{id}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
            transformResponse: (payload) => (0, transform_paths_1.transformPaths)(payload, [
                {
                    transformFn: timestamp_1.transformRESTTimestampToSDKTimestamp,
                    paths: [
                        { path: 'phase.cardsList.cards.info.dueDate' },
                        { path: 'phase.cardsList.cards.info.createdAt' },
                        { path: 'phase.cardsList.cards.info.updatedAt' },
                        { path: 'phase.cardsList.cards.info.createdDate' },
                        { path: 'phase.cardsList.cards.info.updatedDate' },
                    ],
                },
            ]),
            fallback: [
                {
                    method: 'GET',
                    url: resolveComWixpressWorkflowApiV1PhasesServiceUrl({
                        protoPath: '/v1/phases/{id}',
                        data: payload,
                        host,
                    }),
                    params: (0, rest_modules_1.toURLSearchParams)(payload),
                },
            ],
        };
        return metadata;
    }
    return __getPhase;
}
exports.getPhase = getPhase;
/**
 * Updates an existing workflow phase.
 *
 *
 * The `updatePhase()` function returns a Promise that resolves when the phase has been updated with the specified values.
 *
 *
 * Only the properties passed in the `phase` object will be updated. All other properties will remain the same.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
function updatePhase(payload) {
    function __updatePhase({ host }) {
        const metadata = {
            entityFqdn: 'wix.workflows.v1.phase',
            method: 'PATCH',
            methodFqn: 'com.wixpress.workflow.api.v1.PhasesService.UpdatePhase',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressWorkflowApiV1PhasesServiceUrl({
                protoPath: '/v1/phases/{id}',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __updatePhase;
}
exports.updatePhase = updatePhase;
/**
 * Creates a new workflow phase.
 *
 *
 * The `createPhase()` function returns a Promise that resolves to the created phase ID when the phase is created in the specified workflow.
 *
 *
 * Pass a value for the `position` parameter to specify the newly created phase's position within the specified workflow. Positions are zero-based, meaning the first position is `0`.
 *
 *
 * When omitted, the newly created phase is added as the last non-win phase.
 *
 *
 * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
function createPhase(payload) {
    function __createPhase({ host }) {
        const metadata = {
            entityFqdn: 'wix.workflows.v1.phase',
            method: 'POST',
            methodFqn: 'com.wixpress.workflow.api.v1.PhasesService.CreatePhase',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressWorkflowApiV1PhasesServiceUrl({
                protoPath: '/v1/workflows/{workflowId}/phases',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __createPhase;
}
exports.createPhase = createPhase;
/**
 * Deletes a workflow phase.
 *
 *
 * The `deletePhase()` function returns a Promise when the specified phase has been deleted.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
function deletePhase(payload) {
    function __deletePhase({ host }) {
        const metadata = {
            entityFqdn: 'wix.workflows.v1.phase',
            method: 'DELETE',
            methodFqn: 'com.wixpress.workflow.api.v1.PhasesService.DeletePhase',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressWorkflowApiV1PhasesServiceUrl({
                protoPath: '/v1/phases/{id}',
                data: payload,
                host,
            }),
            params: (0, rest_modules_1.toURLSearchParams)(payload),
        };
        return metadata;
    }
    return __deletePhase;
}
exports.deletePhase = deletePhase;
/**
 * Moves a phase to a new position with a workflow.
 *
 *
 * The `movePhase()` function returns a Promise when the specified phase has been moved to the new position.
 *
 *
 * Use the `newPosition` parameter to specify the new phase position within the workflow. Any non-win phase can be moved to any non-win position. The win phase cannot be moved. Positions are zero-based, meaning the first position is `0`.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
function movePhase(payload) {
    function __movePhase({ host }) {
        const metadata = {
            entityFqdn: 'wix.workflows.v1.phase',
            method: 'POST',
            methodFqn: 'com.wixpress.workflow.api.v1.PhasesService.MovePhase',
            packageName: PACKAGE_NAME,
            url: resolveComWixpressWorkflowApiV1PhasesServiceUrl({
                protoPath: '/v1/workflows/{workflowId}/phases/{id}/move',
                data: payload,
                host,
            }),
            data: payload,
        };
        return metadata;
    }
    return __movePhase;
}
exports.movePhase = movePhase;
//# sourceMappingURL=workflows-v1-phase-phases.http.js.map