"use strict";
var __createBinding = (this && this.__createBinding) || (Object.create ? (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    var desc = Object.getOwnPropertyDescriptor(m, k);
    if (!desc || ("get" in desc ? !m.__esModule : desc.writable || desc.configurable)) {
      desc = { enumerable: true, get: function() { return m[k]; } };
    }
    Object.defineProperty(o, k2, desc);
}) : (function(o, m, k, k2) {
    if (k2 === undefined) k2 = k;
    o[k2] = m[k];
}));
var __setModuleDefault = (this && this.__setModuleDefault) || (Object.create ? (function(o, v) {
    Object.defineProperty(o, "default", { enumerable: true, value: v });
}) : function(o, v) {
    o["default"] = v;
});
var __importStar = (this && this.__importStar) || function (mod) {
    if (mod && mod.__esModule) return mod;
    var result = {};
    if (mod != null) for (var k in mod) if (k !== "default" && Object.prototype.hasOwnProperty.call(mod, k)) __createBinding(result, mod, k);
    __setModuleDefault(result, mod);
    return result;
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.movePhase = exports.deletePhase = exports.createPhase = exports.updatePhase = exports.getPhase = exports.listPhases = exports.SortOrder = exports.AttachmentType = void 0;
const transform_error_1 = require("@wix/sdk-runtime/transform-error");
const rename_all_nested_keys_1 = require("@wix/sdk-runtime/rename-all-nested-keys");
const ambassadorWixWorkflowsV1Phase = __importStar(require("./workflows-v1-phase-phases.http.js"));
/** describes the supported types of attachments (currently only supports Contact which is the default type) */
var AttachmentType;
(function (AttachmentType) {
    AttachmentType["ContactType"] = "ContactType";
})(AttachmentType || (exports.AttachmentType = AttachmentType = {}));
var SortOrder;
(function (SortOrder) {
    SortOrder["ASC"] = "ASC";
    SortOrder["DESC"] = "DESC";
})(SortOrder || (exports.SortOrder = SortOrder = {}));
/**
 * Retrieves a list of a workflow's phases.
 *
 *
 * The `listPhases()` function returns a Promise that resolves to a list containing information about the specified workflow's phases.
 *
 *
 * Use the `options` parameter to specify which phases to retrieve and in which order to retrieve them. Phases can be sorted based on their `"id"`, `"name"`, and `"position"`. If no `limit` parameter is passed, the first 50 cards are returned. Sort order defaults to by `"position"` ascending.
 *
 *
 * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param workflowId - ID of the workflow whose phases will be listed.
 * @public
 * @documentationMaturity preview
 * @requiredField workflowId
 * @param options - Options to use when retrieving the list of workflow phases.
 * @permissionId workflows.view
 * @fqn com.wixpress.workflow.api.v1.PhasesService.ListPhases
 */
async function listPhases(workflowId, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        workflowId: workflowId,
        limit: options?.limit,
        offset: options?.offset,
        sort: options?.sort,
    });
    const reqOpts = ambassadorWixWorkflowsV1Phase.listPhases(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                workflowId: '$[0]',
                limit: '$[1].limit',
                offset: '$[1].offset',
                sort: '$[1].sort',
            },
            singleArgumentUnchanged: false,
        }, ['workflowId', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.listPhases = listPhases;
/**
 * Retrieves a phase by ID.
 *
 *
 * The `getPhase()` function returns a Promise that resolves to the phase with the specified ID.
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the phase to retrieve.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @permissionId workflows.view
 * @returns Requested phase.
 * @fqn com.wixpress.workflow.api.v1.PhasesService.GetPhase
 */
async function getPhase(_id) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ id: _id });
    const reqOpts = ambassadorWixWorkflowsV1Phase.getPhase(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data)?.phase;
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { id: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.getPhase = getPhase;
/**
 * Updates an existing workflow phase.
 *
 *
 * The `updatePhase()` function returns a Promise that resolves when the phase has been updated with the specified values.
 *
 *
 * Only the properties passed in the `phase` object will be updated. All other properties will remain the same.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the phase to update.
 * @param phase - Phase details to update.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @requiredField phase
 * @param options - Phase information to update.
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.PhasesService.UpdatePhase
 */
async function updatePhase(_id, phase) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        id: _id,
        phase: phase,
    });
    const reqOpts = ambassadorWixWorkflowsV1Phase.updatePhase(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { id: '$[0]', phase: '$[1]' },
            singleArgumentUnchanged: false,
        }, ['_id', 'phase']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.updatePhase = updatePhase;
/**
 * Creates a new workflow phase.
 *
 *
 * The `createPhase()` function returns a Promise that resolves to the created phase ID when the phase is created in the specified workflow.
 *
 *
 * Pass a value for the `position` parameter to specify the newly created phase's position within the specified workflow. Positions are zero-based, meaning the first position is `0`.
 *
 *
 * When omitted, the newly created phase is added as the last non-win phase.
 *
 *
 * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param workflowId - ID of the workflow to create the phase in.
 * @param phase - Phase details.
 * @public
 * @documentationMaturity preview
 * @requiredField phase
 * @requiredField phase.name
 * @requiredField workflowId
 * @param options - Options to use when creating workflow phases.
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.PhasesService.CreatePhase
 */
async function createPhase(workflowId, phase, options) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[3];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        workflowId: workflowId,
        phase: phase,
        position: options?.position,
    });
    const reqOpts = ambassadorWixWorkflowsV1Phase.createPhase(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
        return (0, rename_all_nested_keys_1.renameKeysFromRESTResponseToSDKResponse)(result.data);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                workflowId: '$[0]',
                phase: '$[1]',
                position: '$[2].position',
            },
            singleArgumentUnchanged: false,
        }, ['workflowId', 'phase', 'options']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.createPhase = createPhase;
/**
 * Deletes a workflow phase.
 *
 *
 * The `deletePhase()` function returns a Promise when the specified phase has been deleted.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param _id - ID of the phase to delete.
 * @public
 * @documentationMaturity preview
 * @requiredField _id
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.PhasesService.DeletePhase
 */
async function deletePhase(_id) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[1];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({ id: _id });
    const reqOpts = ambassadorWixWorkflowsV1Phase.deletePhase(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: { id: '$[0]' },
            singleArgumentUnchanged: false,
        }, ['_id']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.deletePhase = deletePhase;
/**
 * Moves a phase to a new position with a workflow.
 *
 *
 * The `movePhase()` function returns a Promise when the specified phase has been moved to the new position.
 *
 *
 * Use the `newPosition` parameter to specify the new phase position within the workflow. Any non-win phase can be moved to any non-win position. The win phase cannot be moved. Positions are zero-based, meaning the first position is `0`.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 * @param newPosition - New phase position, where the first phase is `0`.
 *
 * If a phase already occupies the specified position,
 * that phase and any subsequent phases
 * are shifted to the right by 1.
 * @public
 * @documentationMaturity preview
 * @requiredField identifiers
 * @requiredField identifiers._id
 * @requiredField identifiers.workflowId
 * @requiredField newPosition
 * @permissionId workflows.modify
 * @fqn com.wixpress.workflow.api.v1.PhasesService.MovePhase
 */
async function movePhase(identifiers, newPosition) {
    // @ts-ignore
    const { httpClient, sideEffects } = arguments[2];
    const payload = (0, rename_all_nested_keys_1.renameKeysFromSDKRequestToRESTRequest)({
        workflowId: identifiers?.workflowId,
        id: identifiers?._id,
        newPosition: newPosition,
    });
    const reqOpts = ambassadorWixWorkflowsV1Phase.movePhase(payload);
    sideEffects?.onSiteCall?.();
    try {
        const result = await httpClient.request(reqOpts);
        sideEffects?.onSuccess?.(result);
    }
    catch (err) {
        const transformedError = (0, transform_error_1.transformError)(err, {
            spreadPathsToArguments: {},
            explicitPathsToArguments: {
                workflowId: '$[0].workflowId',
                id: '$[0]._id',
                newPosition: '$[1]',
            },
            singleArgumentUnchanged: false,
        }, ['identifiers', 'newPosition']);
        sideEffects?.onError?.(err);
        throw transformedError;
    }
}
exports.movePhase = movePhase;
//# sourceMappingURL=workflows-v1-phase-phases.universal.js.map