import { RequestOptionsFactory } from '@wix/sdk-types';
/**
 * Retrieves a list of a workflow's phases.
 *
 *
 * The `listPhases()` function returns a Promise that resolves to a list containing information about the specified workflow's phases.
 *
 *
 * Use the `options` parameter to specify which phases to retrieve and in which order to retrieve them. Phases can be sorted based on their `"id"`, `"name"`, and `"position"`. If no `limit` parameter is passed, the first 50 cards are returned. Sort order defaults to by `"position"` ascending.
 *
 *
 * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function listPhases(payload: object): RequestOptionsFactory<any>;
/**
 * Retrieves a phase by ID.
 *
 *
 * The `getPhase()` function returns a Promise that resolves to the phase with the specified ID.
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function getPhase(payload: object): RequestOptionsFactory<any>;
/**
 * Updates an existing workflow phase.
 *
 *
 * The `updatePhase()` function returns a Promise that resolves when the phase has been updated with the specified values.
 *
 *
 * Only the properties passed in the `phase` object will be updated. All other properties will remain the same.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function updatePhase(payload: object): RequestOptionsFactory<any>;
/**
 * Creates a new workflow phase.
 *
 *
 * The `createPhase()` function returns a Promise that resolves to the created phase ID when the phase is created in the specified workflow.
 *
 *
 * Pass a value for the `position` parameter to specify the newly created phase's position within the specified workflow. Positions are zero-based, meaning the first position is `0`.
 *
 *
 * When omitted, the newly created phase is added as the last non-win phase.
 *
 *
 * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function createPhase(payload: object): RequestOptionsFactory<any>;
/**
 * Deletes a workflow phase.
 *
 *
 * The `deletePhase()` function returns a Promise when the specified phase has been deleted.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function deletePhase(payload: object): RequestOptionsFactory<any>;
/**
 * Moves a phase to a new position with a workflow.
 *
 *
 * The `movePhase()` function returns a Promise when the specified phase has been moved to the new position.
 *
 *
 * Use the `newPosition` parameter to specify the new phase position within the workflow. Any non-win phase can be moved to any non-win position. The win phase cannot be moved. Positions are zero-based, meaning the first position is `0`.
 *
 *
 * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
 */
export declare function movePhase(payload: object): RequestOptionsFactory<any>;
