import { HttpClient } from '@wix/sdk-types';
import { CreatePhaseOptions, CreatePhaseResponse, ListPhasesOptions, ListPhasesResponse, MovePhaseIdentifiers, Phase, PhaseInfo } from './workflows-v1-phase-phases.universal.js';
export declare const __metadata: {
    PACKAGE_NAME: string;
};
export declare function listPhases(httpClient: HttpClient): ListPhasesSignature;
interface ListPhasesSignature {
    /**
     * Retrieves a list of a workflow's phases.
     *
     *
     * The `listPhases()` function returns a Promise that resolves to a list containing information about the specified workflow's phases.
     *
     *
     * Use the `options` parameter to specify which phases to retrieve and in which order to retrieve them. Phases can be sorted based on their `"id"`, `"name"`, and `"position"`. If no `limit` parameter is passed, the first 50 cards are returned. Sort order defaults to by `"position"` ascending.
     *
     *
     * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
     * @param - ID of the workflow whose phases will be listed.
     * @param - Options to use when retrieving the list of workflow phases.
     */
    (workflowId: string, options?: ListPhasesOptions | undefined): Promise<ListPhasesResponse>;
}
export declare function getPhase(httpClient: HttpClient): GetPhaseSignature;
interface GetPhaseSignature {
    /**
     * Retrieves a phase by ID.
     *
     *
     * The `getPhase()` function returns a Promise that resolves to the phase with the specified ID.
     *
     * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
     * @param - ID of the phase to retrieve.
     * @returns Requested phase.
     */
    (_id: string): Promise<Phase>;
}
export declare function updatePhase(httpClient: HttpClient): UpdatePhaseSignature;
interface UpdatePhaseSignature {
    /**
     * Updates an existing workflow phase.
     *
     *
     * The `updatePhase()` function returns a Promise that resolves when the phase has been updated with the specified values.
     *
     *
     * Only the properties passed in the `phase` object will be updated. All other properties will remain the same.
     *
     *
     * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
     * @param - ID of the phase to update.
     * @param - Phase details to update.
     * @param - Phase information to update.
     */
    (_id: string, phase: PhaseInfo): Promise<void>;
}
export declare function createPhase(httpClient: HttpClient): CreatePhaseSignature;
interface CreatePhaseSignature {
    /**
     * Creates a new workflow phase.
     *
     *
     * The `createPhase()` function returns a Promise that resolves to the created phase ID when the phase is created in the specified workflow.
     *
     *
     * Pass a value for the `position` parameter to specify the newly created phase's position within the specified workflow. Positions are zero-based, meaning the first position is `0`.
     *
     *
     * When omitted, the newly created phase is added as the last non-win phase.
     *
     *
     * This function requires you to specify the ID of a workflow. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
     * @param - ID of the workflow to create the phase in.
     * @param - Phase details.
     * @param - Options to use when creating workflow phases.
     */
    (workflowId: string, phase: PhaseInfo, options?: CreatePhaseOptions | undefined): Promise<CreatePhaseResponse>;
}
export declare function deletePhase(httpClient: HttpClient): DeletePhaseSignature;
interface DeletePhaseSignature {
    /**
     * Deletes a workflow phase.
     *
     *
     * The `deletePhase()` function returns a Promise when the specified phase has been deleted.
     *
     *
     * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
     * @param - ID of the phase to delete.
     */
    (_id: string): Promise<void>;
}
export declare function movePhase(httpClient: HttpClient): MovePhaseSignature;
interface MovePhaseSignature {
    /**
     * Moves a phase to a new position with a workflow.
     *
     *
     * The `movePhase()` function returns a Promise when the specified phase has been moved to the new position.
     *
     *
     * Use the `newPosition` parameter to specify the new phase position within the workflow. Any non-win phase can be moved to any non-win position. The win phase cannot be moved. Positions are zero-based, meaning the first position is `0`.
     *
     *
     * This function requires you to specify the ID of a phase. To learn about retrieving IDs in the Workflows APIs, see [Retrieving IDs](wix-workflows-v2/introduction#retrieving-ids).
     * @param - New phase position, where the first phase is `0`.
     *
     * If a phase already occupies the specified position,
     * that phase and any subsequent phases
     * are shifted to the right by 1.
     */
    (identifiers: MovePhaseIdentifiers, newPosition: number): Promise<void>;
}
export { Attachment, AttachmentType, Card, CardInfo, CardsList, CreatePhaseOptions, CreatePhaseRequest, CreatePhaseResponse, DeletePhaseRequest, DeletePhaseResponse, GetPhaseRequest, GetPhaseResponse, ListPhasesOptions, ListPhasesRequest, ListPhasesResponse, MovePhaseIdentifiers, MovePhaseRequest, MovePhaseResponse, PaginationResponse, Paging, Phase, PhaseInfo, Query, QueryPhasesRequest, QueryPhasesResponse, SortOrder, Sorting, UpdatePhaseRequest, UpdatePhaseResponse, } from './workflows-v1-phase-phases.universal.js';
